package pl.mbdev.xml;

/**
 * Superclass for objects that are convertible to XML.
 * 
 * <pre>
 * Copyright 2011 Mateusz Bysiek,
 *     mb@mbdev.pl, http://mbdev.pl/
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *     http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 * </pre>
 * 
 * @author Mateusz Bysiek
 */
public abstract class XmlObject extends Object implements Xml {
	
	/**
	 * Converts this object to string representing it in XML.
	 * 
	 * @return string that is XML compatible
	 */
	public String toXmlString() {
		return this.toXml().toXmlString();
	}
	
	/**
	 * Gets XML data specific for the current objects, and adds them to the default
	 * contents of the tree.
	 * 
	 * @param t
	 *           default tree
	 * @return reference to the updated tree
	 */
	protected abstract XmlTree getXmlData(XmlTree t);
	
	@Override
	public XmlTree toXml() {
		XmlTree t = new XmlTree();
		
		t.setName(XmlTree.createName(this));
		t.setDtdUrl(XmlTree.createDtdUrl(
				new StringBuffer("http://mbdev.pl").append("/files/xmlserver").toString(),
				t.getName()));
		t = this.getXmlData(t);
		
		return t;
	}
	
	@Override
	public String toString() {
		return super.toString();
	}
	
}
